Enum CombatResult
#[repr(u8)]pub enum CombatResult {
Show 20 variants
StrikeDamage = 0,
StrikeDamageCrit = 1,
StrikeDamageGlance = 2,
Block = 3,
Evade = 4,
Interrupt = 5,
Absorb = 6,
Blind = 7,
KillingBlow = 8,
Downed = 9,
BreakbarDamage = 10,
SkillCast = 11,
CrowdControl = 12,
Invert = 13,
BuffDamageCycle = 14,
BuffDamageNotCycle = 15,
BuffDamageTargetOnHit = 16,
BuffDamageSourceOnHit = 17,
BuffDamageOnBuffRemove = 18,
Unknown(u8),
}Expand description
Combat result.
Variants
StrikeDamage = 0
Strike damage.
No critical hit, no glance.
StrikeDamageCrit = 1
Critical strike damage.
StrikeDamageGlance = 2
Glancing strike damage.
Block = 3
Attack was blocked.
Due to Aegis, Chrono Shield 4 etc.
Evade = 4
Attack was evaded.
Due to dodge, Mesmer Sword 2 etc.
Interrupt = 5
Action was interrupted.
Absorb = 6
Attack was absorbed.
Usually due to an invulnerability like Guardian Renewed Focus.
Blind = 7
Attack missed.
Due to blind etc.
KillingBlow = 8
Attack killed the target.
Downed = 9
Attack downed the target.
BreakbarDamage = 10
Attack dealt breakbar damage.
SkillCast = 11
On-skill-activation event.
CrowdControl = 12
Skill crowd controlled the target.
Invert = 13
Damage was inverted.
BuffDamageCycle = 14
Regular buff damage on cycle.
BuffDamageNotCycle = 15
Buff damage outside of cycle.
BuffDamageTargetOnHit = 16
Buff damage to target on hitting target (outside of cycle).
BuffDamageSourceOnHit = 17
Buff damage to source on hitting target (outside of cycle).
BuffDamageOnBuffRemove = 18
Buff damage to target on buff removal (outside of cycle).
Unknown(u8)
Unknown.
Implementations
impl CombatResult
impl CombatResult
pub const fn is_health_damage(&self) -> bool
pub const fn is_health_damage(&self) -> bool
Whether the attack dealt health damage to the target.
pub const fn is_strike_damage(&self) -> bool
pub const fn is_strike_damage(&self) -> bool
Whether the attack dealt strike damage to the target.
pub const fn is_buff_damage(&self) -> bool
pub const fn is_buff_damage(&self) -> bool
Whether the attack dealt buff damage to the target.
pub const fn is_breakbar_damage(&self) -> bool
pub const fn is_breakbar_damage(&self) -> bool
Whether the attack dealt breabkar damage to the target.
pub const fn is_pervented(&self) -> bool
pub const fn is_pervented(&self) -> bool
Whether the attack was prevented