Event

Struct Event 

#[repr(C)]
pub struct Event {
Show 27 fields pub time: u64, pub src_agent: u64, pub dst_agent: u64, pub value: i32, pub buff_dmg: i32, pub overstack_value: u32, pub skill_id: u32, pub src_instance_id: u16, pub dst_instance_id: u16, pub src_master_instance_id: u16, pub dst_master_instance_id: u16, pub affinity: u8, pub buff: u8, pub result: u8, pub is_activation: u8, pub is_buffremove: u8, pub is_ninety: u8, pub is_fifty: u8, pub is_moving: u8, pub is_statechange: u8, pub is_flanking: u8, pub is_shields: u8, pub is_offcycle: u8, pub pad61: u8, pub pad62: u8, pub pad63: u8, pub pad64: u8,
}
ArcDPS event.

Fields

time: u64

timeGetTime() at time of registering the event.

src_agent: u64

Agent that caused the event.

dst_agent: u64

Agent the event happened to.

value: i32

Value, if relevant to the event.

buff_dmg: i32

Buff damage, if relevant to the event.

overstack_value: u32

Overstack value, if relevant to the event.

skill_id: u32

Skill id of the relevant skill (can be zero).

src_instance_id: u16

Instance id of source agent as appears in game at time of event.

dst_instance_id: u16

Instance id of destination agent as appears in game at time of event.

src_master_instance_id: u16

If src_agent has a master (e.g. is minion), will be equal to instance id of master, zero otherwise.

dst_master_instance_id: u16

If dst_agent has a master (e.g. is minion), will be equal to instance id of master, zero otherwise.

affinity: u8

Current affinity of src_agent and dst_agent.

Use Event::get_affinity to obtain the value as Affinity.

Arc calls this “iff” for if friend/foe.

buff: u8

Buff, if relevant to the event.

result: u8

Combat result for combat events.

is_activation: u8

Whether event is a kind of activation event.

Use Event::get_animation_progress to obtain the value as AnimationProgress.

is_buffremove: u8

Whether event is a kind of buff remove event.

Use Event::get_buff_remove to obtain the value as BuffRemove.

is_ninety: u8

Whether src_agent is above 90% Health.

is_fifty: u8

Whether dst_agent is below 50% Health.

is_moving: u8

Whether src_agent is moving at time of event.

is_statechange: u8

Whether event is a kind of state change event.

Use Event::get_statechange to obtain the value as StateChange.

is_flanking: u8

Whether src_agent is flanking at time of event.

The value lies in a range of 1 to 135 degrees where 135 is rear.

is_shields: u8

Shields, if relevant to the event.

is_offcycle: u8

For relevant events this contains when the buff cycle happened.

Use [Event::get_buffcycle] to obtain the value as [BuffCycle].

pad61: u8

Padding.

May contain information depending on the kind of event.

pad62: u8

Padding.

May contain information depending on the kind of event.

pad63: u8

Padding.

May contain information depending on the kind of event.

pad64: u8

Padding.

May contain information depending on the kind of event.

Implementations



impl Event

pub fn into_kind(self) -> EventKind

Converts the event into its EventKind representation.

pub fn into_legacy(self) -> LegacyEventKind

Converts the event into its LegacyEventKind representation.

pub fn is_legacy(&self) -> bool

Checks whether the event is a legacy event.

pub unsafe fn extract<T>(&self) -> T
where T: Extract,

Forcefully extracts a type implementing Extract from the event.

Safety

This is safe when the given event is a valid event to extract the type from.

pub fn try_extract<T>(&self) -> Option<T>
where T: TryExtract,

Attempts to extract a type implementing TryExtract from the event.

pub fn get_statechange(&self) -> StateChange

Returns the event is_statechange as StateChange.

pub fn get_affinity(&self) -> Affinity

Returns the event affinity as Affinity.

This will return Affinity::Unknown if the event has no valid data in affinity.

pub fn get_combat_result(&self) -> CombatResult

Returns result as CombatResult.

pub fn get_animation_progress(&self) -> AnimationProgress

Returns is_activation as AnimationProgress.

pub fn get_buff_remove(&self) -> BuffRemove

Returns is_buffremove as BuffRemove.

pub fn get_pad_id(&self) -> u32

Returns the padding as u32 id/signature.

pub fn has_time(&self) -> bool

Checks whether the event has a timestamp.

pub fn time(&self) -> Option<u64>

Retrieves the event time, if present.

pub fn is_buffinitial(&self) -> bool

Checks whether the event is an initial buff event.

pub fn is_source_moving(&self) -> bool

Checks whether the source is moving, if applicable for this event type.

pub fn is_target_moving(&self) -> bool

Checks whether the target is moving, if applicable for this event type.