Struct Ruleset
pub struct Ruleset(/* private fields */);Implementations
impl Ruleset
impl Ruleset
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<Ruleset>
pub const fn from_bits(bits: u64) -> Option<Ruleset>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> Ruleset
pub const fn from_bits_truncate(bits: u64) -> Ruleset
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> Ruleset
pub const fn from_bits_retain(bits: u64) -> Ruleset
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Ruleset>
pub fn from_name(name: &str) -> Option<Ruleset>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Ruleset) -> bool
pub const fn intersects(&self, other: Ruleset) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Ruleset) -> bool
pub const fn contains(&self, other: Ruleset) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Ruleset)
pub fn remove(&mut self, other: Ruleset)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: Ruleset, value: bool)
pub fn set(&mut self, other: Ruleset, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Ruleset) -> Ruleset
pub const fn intersection(self, other: Ruleset) -> Ruleset
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Ruleset) -> Ruleset
pub const fn union(self, other: Ruleset) -> Ruleset
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Ruleset) -> Ruleset
pub const fn difference(self, other: Ruleset) -> Ruleset
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Ruleset) -> Ruleset
pub const fn symmetric_difference(self, other: Ruleset) -> Ruleset
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Ruleset
pub const fn complement(self) -> Ruleset
The bitwise negation (!) of the bits in self, truncating the result.
impl Ruleset
impl Ruleset
pub const fn iter(&self) -> Iter<Ruleset>
pub const fn iter(&self) -> Iter<Ruleset>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Ruleset>
pub const fn iter_names(&self) -> IterNames<Ruleset>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.